=========================
 Invenio-XRootD v1.0.0a4
=========================

Invenio-XRootD v1.0.0a4 was released on January 18, 2017.

About
-----

XRootD file storage support for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-xrootd==1.0.0a4

Documentation
-------------

   http://invenio-xrootd.readthedocs.io/

Happy hacking and thanks for flying Invenio-XRootD.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-xrootd
|   URL: http://inveniosoftware.org
